@@ -1,6 +1,6 @@
 getDisjCommAnc <-
 function(term1, term2){
-	if(!exists("DOSimEnv")) initialize()
+	if(!exists("DOSimEnv")) initialize_DOSimEnv()
 	ancestor<-get("ancestor",envir=DOSimEnv)
 	#load("DOAncestor.rda")
 	IC<-get("IC", envir=DOSimEnv)
